@@ -249,6 +249,10 @@ class LoadMaster(HttpClient):
         response = self._post('/installpatch', file)
         return is_successful(response)
 
+    def restore_firmware(self):
+        response = self._get("/restorepatch")
+        return is_successful(response)
+
     def shutdown(self):
         response = self._get('/shutdown')
         return is_successful(response)
